Learn R Programming

evsim (version 1.7.1)

california_ev_sessions: EV charging sessions example

Description

Example of an charging sessions data set ready to use by evprof functions. It is the open source data set downloaded from the ACN-Data website, transformed according to the standard names defined by evprof

Usage

california_ev_sessions

Arguments

Format

california_ev_sessions

A tibble object with standard variable names defined by evprof