powered by
Example of a charging sessions data set that has been clustered by evprof functions
evprof
california_ev_sessions_profiles
A tibble object with standard variable names defined by evprof
tibble