| expand_sessions | R Documentation |
Every session in sessions is divided in multiple time slots
with the corresponding Power consumption, among other variables.
expand_sessions(sessions, resolution)
sessions |
tibble, sessions data set in standard format marked by |
resolution |
integer, time resolution (in minutes) of the time slots |
The Power value is calculated for every time slot according to the original
required energy. The columns PowerNominal, EnergyRequired and
FlexibilityHours correspond to the values of the original session, and not
to the expanded session in every time slot. The column ID shows the number
of the time slot corresponding to the original session.
tibble
library(dplyr)
sessions <- head(evsim::california_ev_sessions, 10)
expand_sessions(
sessions,
resolution = 60
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.