get_charging_rates_distribution: Charging rates distribution
Description
Get charging rates distribution in percentages from a charging sessions data set
Usage
get_charging_rates_distribution(sessions, unit = "year", power_interval = NULL)
Value
tibble
Arguments
sessions
tibble, sessions data set in standard format marked by {evprof} package
unit
character. Valid base units are second, minute, hour, day,
week, month, bimonth, quarter, season, halfyear and year.
It corresponds to unit parameter in lubridate::floor_date function.
power_interval
numeric, interval of kW between power rates.
It is used to round the Power values into this interval resolution.
It can also be NULL to use all the original Power values.